import sys

from loguru import logger

from . import LogLevelEnum


def logger_init(log_level: LogLevelEnum) -> None:
    logger.remove()
    extra = {"request_id": "SYSTEM_LOG"}
    format_ = "{time:DD-MM-YYYY HH:mm:ss} | <level>{level: <8}</level> | {extra[request_id]}"
    format_ = f"{format_} | <level>{{message}}</level>"
    logger.add(sys.stdout, colorize=True, format=format_, level=log_level)
    logger.configure(extra=extra)


def log_llm_error(
    text: str | None = None,
    vector: list[float] | None = None,
    model: str = "gigachat",
) -> None:
    if text is not None and not text:
        logger.error(f"No response from {model}!!!")
        return None
    if vector is not None and all(not item for item in vector):
        logger.error(f"No response from {model} encoder!!!")
        return None
    return None



from enum import StrEnum, auto


class DoctorChoiceXMLTagEnum(StrEnum):
    @staticmethod
    def _generate_next_value_(name: str, start: int, count: int, last_values: list[str]) -> str:
        return f"{name.lower()}"

    DIAGNOSTICS = auto()
    SUMMARIZATION = auto()
    MTRS = auto()



from ._base import _Base

from .enums import TrackIdEnum, StateEnum, MTRSLabelEnum, ActionEnum, ModerationLabelEnum
from .enums import DiagnosticsXMLTagEnum, MTRSXMLTagEnum, DoctorChoiceXMLTagEnum

from .chat_item import ChatItem, OuterContextItem, InnerContextItem, ReplicaItem, ReplicaItemPair
from .base_config_models import GigaChatConfig



from enum import StrEnum, auto


class ActionEnum(StrEnum):
    START = auto()

    GREETING = auto()
    MODERATION = auto()
    ANSWER = auto()
    QUESTION = auto()
    CRITICAL = auto()
    MED_TEST_DECRYPTION = auto()

    DIAGNOSIS = auto()
    REPORT = auto()
    FINANCIAL_EXTRACTION = auto()
    FINAL = auto()
